==> paraview_3.8.0.orig.tar.gz: ParaView-3.8.0/Applications/AdaptiveParaView/Plugin/vtkACosmoReader.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkACosmoReader.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/*=========================================================================

  Program:   VTK/ParaView Los Alamos National Laboratory Modules (PVLANL)
  Module:    vtkACosmoReader.h

Copyright (c) 2007, 2009 Los Alamos National Security, LLC

All rights reserved.

Copyright 2007, 2009. Los Alamos National Security, LLC. 
This software was produced under U.S. Government contract DE-AC52-06NA25396 
for Los Alamos National Laboratory (LANL), which is operated by 
Los Alamos National Security, LLC for the U.S. Department of Energy. 
The U.S. Government has rights to use, reproduce, and distribute this software. 
NEITHER THE GOVERNMENT NOR LOS ALAMOS NATIONAL SECURITY, LLC MAKES ANY WARRANTY,
EXPRESS OR IMPLIED, OR ASSUMES ANY LIABILITY FOR THE USE OF THIS SOFTWARE.  
If software is modified to produce derivative works, such modified software 
should be clearly marked, so as not to confuse it with the version available 
from LANL.
 
Additionally, redistribution and use in source and binary forms, with or 
without modification, are permitted provided that the following conditions 
are met:
-   Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer. 
-   Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution. 
-   Neither the name of Los Alamos National Security, LLC, Los Alamos National
    Laboratory, LANL, the U.S. Government, nor the names of its contributors
    may be used to endorse or promote products derived from this software 
    without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY LOS ALAMOS NATIONAL SECURITY, LLC AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL LOS ALAMOS NATIONAL SECURITY, LLC OR 
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkACosmoReader - Adaptively read a binary cosmology data file
//

#ifndef __vtkACosmoReader_h
#define __vtkACosmoReader_h

#include "vtkUnstructuredGridAlgorithm.h"

class vtkDataArraySelection;
class vtkStdString;

class VTK_IO_EXPORT vtkACosmoReader : public vtkUnstructuredGridAlgorithm
{
public:
  static vtkACosmoReader *New();
  vtkTypeMacro(vtkACosmoReader, vtkUnstructuredGridAlgorithm);
  virtual void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Specify the name of the cosmology particle binary file to read
  vtkSetStringMacro(FileName);
  vtkGetStringMacro(FileName);

  // Set/Get the box size for the simulation (range along x,y,z)
  // Negative x,y,z values are subtracted from this for wraparound
  vtkSetMacro(BoxSize, double);
  vtkGetMacro(BoxSize, double);

  // Description:
  // Set/Get the endian-ness of the binary file
  vtkSetMacro(ByteOrder, int);
  vtkGetMacro(ByteOrder, int);

  // Description:
  // When false (default) 32-bit tags are read from the file.  When
  // on, 64-bit tags are read from the file.
  vtkSetMacro(TagSize, int);
  vtkGetMacro(TagSize, int);

protected:
  vtkACosmoReader();
  ~vtkACosmoReader();
 
  virtual int RequestInformation(vtkInformation *, 
    vtkInformationVector **, vtkInformationVector *);
  virtual int RequestData(vtkInformation *, 
    vtkInformationVector **, vtkInformationVector *);
  virtual int ProcessRequest
    (vtkInformation *, vtkInformationVector **,
     vtkInformationVector *);

  virtual int ReadFile(vtkUnstructuredGrid *);

  char* FileName; // Name of binary particle file
  double BoxSize; // Maximum of x,y,z locations from simulation
  int ByteOrder; // Endian
  int TagSize; // Size of the tag, 0 = 32-bit or 1 = 64-bit

  ifstream *FileStream; // Data stream
  double Resolution;
  int PieceNumber;
  float* pieceBounds;
  int maxlevel;
  int splits;
  vtkIdType currentLevel;

private:
  vtkACosmoReader(const vtkACosmoReader&);  // Not implemented.
  void operator=(const vtkACosmoReader&);  // Not implemented.
};

#endif

==> paraview_3.8.1.orig.tar.gz: ParaView-3.8.1/Applications/AdaptiveParaView/Plugin/vtkACosmoReader.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkACosmoReader.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/*=========================================================================

  Program:   VTK/ParaView Los Alamos National Laboratory Modules (PVLANL)
  Module:    vtkACosmoReader.h

Copyright (c) 2007, 2009 Los Alamos National Security, LLC

All rights reserved.

Copyright 2007, 2009. Los Alamos National Security, LLC. 
This software was produced under U.S. Government contract DE-AC52-06NA25396 
for Los Alamos National Laboratory (LANL), which is operated by 
Los Alamos National Security, LLC for the U.S. Department of Energy. 
The U.S. Government has rights to use, reproduce, and distribute this software. 
NEITHER THE GOVERNMENT NOR LOS ALAMOS NATIONAL SECURITY, LLC MAKES ANY WARRANTY,
EXPRESS OR IMPLIED, OR ASSUMES ANY LIABILITY FOR THE USE OF THIS SOFTWARE.  
If software is modified to produce derivative works, such modified software 
should be clearly marked, so as not to confuse it with the version available 
from LANL.
 
Additionally, redistribution and use in source and binary forms, with or 
without modification, are permitted provided that the following conditions 
are met:
-   Redistributions of source code must retain the above copyright notice, 
    this list of conditions and the following disclaimer. 
-   Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution. 
-   Neither the name of Los Alamos National Security, LLC, Los Alamos National
    Laboratory, LANL, the U.S. Government, nor the names of its contributors
    may be used to endorse or promote products derived from this software 
    without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY LOS ALAMOS NATIONAL SECURITY, LLC AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL LOS ALAMOS NATIONAL SECURITY, LLC OR 
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkACosmoReader - Adaptively read a binary cosmology data file
//

#ifndef __vtkACosmoReader_h
#define __vtkACosmoReader_h

#include "vtkUnstructuredGridAlgorithm.h"

class vtkDataArraySelection;
class vtkStdString;

class VTK_EXPORT vtkACosmoReader : public vtkUnstructuredGridAlgorithm
{
public:
  static vtkACosmoReader *New();
  vtkTypeMacro(vtkACosmoReader, vtkUnstructuredGridAlgorithm);
  virtual void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Specify the name of the cosmology particle binary file to read
  vtkSetStringMacro(FileName);
  vtkGetStringMacro(FileName);

  // Set/Get the box size for the simulation (range along x,y,z)
  // Negative x,y,z values are subtracted from this for wraparound
  vtkSetMacro(BoxSize, double);
  vtkGetMacro(BoxSize, double);

  // Description:
  // Set/Get the endian-ness of the binary file
  vtkSetMacro(ByteOrder, int);
  vtkGetMacro(ByteOrder, int);

  // Description:
  // When false (default) 32-bit tags are read from the file.  When
  // on, 64-bit tags are read from the file.
  vtkSetMacro(TagSize, int);
  vtkGetMacro(TagSize, int);

protected:
  vtkACosmoReader();
  ~vtkACosmoReader();
 
  virtual int RequestInformation(vtkInformation *, 
    vtkInformationVector **, vtkInformationVector *);
  virtual int RequestData(vtkInformation *, 
    vtkInformationVector **, vtkInformationVector *);
  virtual int ProcessRequest
    (vtkInformation *, vtkInformationVector **,
     vtkInformationVector *);

  virtual int ReadFile(vtkUnstructuredGrid *);

  char* FileName; // Name of binary particle file
  double BoxSize; // Maximum of x,y,z locations from simulation
  int ByteOrder; // Endian
  int TagSize; // Size of the tag, 0 = 32-bit or 1 = 64-bit

  ifstream *FileStream; // Data stream
  double Resolution;
  int PieceNumber;
  float* pieceBounds;
  int maxlevel;
  int splits;
  vtkIdType currentLevel;

private:
  vtkACosmoReader(const vtkACosmoReader&);  // Not implemented.
  void operator=(const vtkACosmoReader&);  // Not implemented.
};

#endif
